@@ -15,7 +15,7 @@ import time
 
 from PyQt5.QtCore import pyqtSignal
 from qtpy import QtWidgets, QtGui
-from qtpy.QtWidgets import QFrame, QInputDialog, QApplication, QMainWindow
+from qtpy.QtWidgets import QFrame, QInputDialog, QApplication, QMainWindow, QMessageBox
 
 from pyxllib.prog.newbie import CvtType
 
@@ -194,99 +194,8 @@ def get_input_widget(items=None, cur_value=None, *, valcvt=None,
     return w
 
 
-def newIcon(icon):
-    icons_dir = osp.join(here, "../icons")
-    return QtGui.QIcon(osp.join(":/", icons_dir, "%s.png" % icon))
-
-
-def newAction(
-        parent,
-        text,
-        slot=None,
-        shortcut=None,
-        icon=None,
-        tip=None,
-        checkable=False,
-        enabled=True,
-        checked=False,
-):
-    """Create a new action and assign callbacks, shortcuts, etc."""
-    a = QtWidgets.QAction(text, parent)
-    if icon is not None:
-        a.setIconText(text.replace(" ", "\n"))
-        a.setIcon(newIcon(icon))
-    if shortcut is not None:
-        if isinstance(shortcut, (list, tuple)):
-            a.setShortcuts(shortcut)
-        else:
-            a.setShortcut(shortcut)
-    if tip is not None:
-        a.setToolTip(tip)
-        a.setStatusTip(tip)
-    if slot is not None:
-        a.triggered.connect(slot)
-    if checkable:
-        a.setCheckable(True)
-    a.setEnabled(enabled)
-    a.setChecked(checked)
-    return a
-
-
-class XlActionFunc:
-    """ 跟action有关的函数调用封装 （该类也可以作为基础的check版本使用）
-
-    一般逻辑结构是这样：
-        有个可运行功能的函数func，运行时会配置一些需要存储起来的变量值value
-        并且功能需要关联action，绑定到menu等菜单中时，可以使用该装饰器
-    """
-
-    def __init__(self, parent, title, value=None, checked=None, **kwargs):
-        self.parent = parent
-        self.title = title
-        self.value = value
-        self.checked = bool(checked)
-        self.checkable = checked is not None
-
-        self.action = newAction(self.parent, self.parent.tr(self.title), self.__call__,
-                                checkable=self.checkable, checked=self.checked, **kwargs)
-
-    def __call__(self, checked):
-        self.checked = checked
-
-
-class GetMultiLineTextAction(XlActionFunc):
-    """ 该类value是直接存储原始的完整文本内容 """
-
-    def __call__(self, checked):
-        super().__call__(checked)
-        self.value = self.value or ''
-        inputs = QInputDialog.getMultiLineText(self.parent, self.title, '编辑文本：', self.value)
-        if inputs[1]:  # “确定操作” 才更新属性
-            self.value = inputs[0]
-
-
-class GetItemsAction(XlActionFunc):
-    """ 该类value目前是存储为list类型 """
-
-    def __call__(self, checked):
-        super().__call__(checked)
-        self.value = self.value or []
-        inputs = QInputDialog.getMultiLineText(self.parent, self.title, '编辑多行文本：',
-                                               '\n'.join(self.value))
-        if inputs[1]:  # “确定操作” 才更新属性
-            self.value = inputs[0].splitlines()
-
-
-class GetJsonAction(XlActionFunc):
-    """ 该类value是直接存储原始的完整文本内容 """
-
-    def __call__(self, checked):
-        super().__call__(checked)
-        self.value = self.value or ''
-        inputs = QInputDialog.getMultiLineText(self.parent, self.title, '编辑json数据：',
-                                               json.dumps(self.value, indent=2))
-        if inputs[1]:  # “确定操作” 才更新属性
-            self.value = json.loads(inputs[0])
+def __other():
+    pass
 
 
 def main_qapp(window):
@@ -342,3 +251,31 @@ def qt_clipboard_monitor(func=None, verbose=1, *, cooldown=0.5):
 class XlMainWindow(QMainWindow):
     """ 根据自己开发app经验，封装一些常用的功能接口，简化代码量 """
     pass
+
+
+class WaitMessageBox(QMessageBox):
+    """ 在执行需要一定时长的程序时，弹出提示窗，并在执行完功能后自动退出提示窗
+
+    【示例】
+    with WaitMessageBox(self.mainwin, 'PaddleOCR模型初始化中，请稍等一会...'):
+        from pyxlpr.paddleocr import PaddleOCR
+        self.ppocr = PaddleOCR.build_ppocr()
+    """
+    finished = pyqtSignal()
+
+    def __init__(self, parent=None, text=None):
+        super().__init__(parent)
+        if text:
+            self.setText(text)
+        self.setStyleSheet("QLabel{min-width: 350px;}")
+        self.setWindowTitle('WaitMessageBox（任务完成后会自动退出该窗口）')
+        self.setStandardButtons(QMessageBox.NoButton)
+        self.finished.connect(self.accept)
+
+    def __enter__(self):
+        self.show()
+        QApplication.processEvents()
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        self.finished.emit()
