@@ -21,11 +21,11 @@ from humanfriendly import format_size
 
 from pyxllib.algo.pupil import SearchBase
 from pyxllib.debug.pupil import dprint
-from pyxllib.debug.specialist import browser, getmembers
+from pyxllib.debug.specialist import browser
 from pyxllib.prog.newbie import round_int
 from pyxllib.prog.pupil import EnchantBase, EnchantCvt, run_once
 from pyxllib.text.newbie import xldictstr
-from pyxllib.text.pupil import shorten, ensure_gbk, RunOnlyOnce, BookContents, strwidth, grp_chinese_char
+from pyxllib.text.pupil import shorten, ensure_gbk, BookContents, strwidth, grp_chinese_char
 from pyxllib.file.specialist import File, Dir, get_etag
 
 
@@ -360,6 +360,7 @@ class EnchantBs4Tag(EnchantBase):
 
         会同时检查NavigableString类型，且必须是空白字符串，比如空格、\n之类
         """
+
         def check(x):
             if isinstance(x, bs4.element.Tag):
                 return True
